@@ -84,7 +84,7 @@
 #' hc <- hclust(dist(x_nonoise), method = "single")
 #' plot(x, pch = 19, cex = .5)
 #' points(x_nonoise, pch = 19, col= cutree(hc, k = 4) + 1L)
-#' @export pointdensity
+#' @export
 pointdensity <- function(x,
   eps,
   type = "frequency",
@@ -97,6 +97,9 @@ pointdensity <- function(x,
   search <- .parse_search(search)
   splitRule <- .parse_splitRule(splitRule)
 
+  if (any(is.na(x)))
+    stop("missing values are not allowed in x.")
+
   d <- dbscan_density_int(
     as.matrix(x),
     as.double(eps),
